netapp_ontap.models.network_route_for_svm API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.network_route_for_svm`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NetworkRouteForSvmSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NetworkRouteForSvm object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `destination GET POST PATCH`

    The destination field of the network_route_for_svm.

  `gateway GET POST PATCH`

    The IP address of the gateway router leading to the destination.

    Example: 10.1.1.1